@@ -19,13 +19,12 @@
 # -- Project information -----------------------------------------------------
 import os
 
-
 project = 'Unimatrix Core'
-copyright = '2020, Cochise Ruhulessin'
+copyright = '2020-2021, Cochise Ruhulessin'
 author = 'Cochise Ruhulessin'
 
 # The full version, including alpha/beta/rc tags
-release = os.getenv('SEMVER_RELEASE') or '1.0.0'
+release = os.getenv('SEMVER_RELEASE') or '0.0.1'
 
 
 # -- General configuration ---------------------------------------------------
@@ -48,7 +47,9 @@ templates_path = ['_templates']
 # This pattern also affects html_static_path and html_extra_path.
 exclude_patterns = []
 
-intersphinx_mapping = {}
+intersphinx_mapping = {
+    'python': ('https://docs.python.org/3', None)
+}
 
 
 
@@ -57,9 +58,33 @@ intersphinx_mapping = {}
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'python_docs_theme'
+html_theme = 'sphinx_material'
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ['_static']
+
+# These paths are either relative to html_static_path
+# or fully qualified paths (eg. https://...)
+html_css_files = [
+    'css/style.css',
+]
+
+# Material theme options (see theme.conf for more information)
+html_show_sourcelink = True
+html_sidebars = {
+    "**": ["logo-text.html", "globaltoc.html", "localtoc.html", "searchbox.html"]
+}
+html_theme_options = {
+    'nav_title': 'Unimatrix',
+    'google_analytics_account': 'UA-XXXXX',
+    'color_primary': 'blue',
+    'color_accent': 'light-blue',
+    'master_doc': False,
+    'repo_url': 'https://gitlab.com/unimatrixone/libraries/python-unimatrix/unimatrix',
+    'repo_name': 'View source code',
+    'globaltoc_depth': 3,
+    'globaltoc_collapse': False,
+    'globaltoc_includehidden': False,
+}
