@@ -5,6 +5,7 @@ import jinja2
 import yaml
 
 from unimatrix.const import ETCDIR
+from unimatrix.const import UNIMATRIX_CONFIG_FILE
 from .datastructures import DTO
 
 
@@ -25,6 +26,14 @@ def load(path, *args, **kwargs) -> dict:
     """Loads the configuration from the specified path."""
     if not os.path.isabs(path):
         path = os.path.join(ETCDIR, path)
+    if not os.path.exists(path):
+        return None
+
     with open(path, 'r') as f:
         etc = render(f.read(), **kwargs)
     return DTO.fromdict(yaml.safe_load(etc))
+
+
+def unimatrix():
+    """Loads settings from the Unimatrix Configuration File."""
+    return load(UNIMATRIX_CONFIG_FILE)
