@@ -1,6 +1,8 @@
 """The :mod:`unimatrix.runtime` package provides a common interface to set
 up the application runtime environment.
 """
+import asyncio
+import importlib
 import inspect
 import pkg_resources
 import os
@@ -25,6 +27,17 @@ def get_entrypoints(name):
     return sorted(entrypoints, key=lambda x: getattr(x[1], 'WEIGHT', 0))
 
 
+def execute(func, *args, **kwargs):
+    """Setup the Unimatrix environment and run `func`."""
+    async def f():
+        await on('boot')
+        try:
+            return await func(*args, **kwargs)
+        finally:
+            await on('shutdown')
+    return asyncio.run(f())
+
+
 @meta.allow_sync
 async def setup():
     """Setup all :mod:`unimatrix` components."""
@@ -81,7 +94,7 @@ async def on(name, *args, runlevel=None, **kwargs):
     if qualname is None:
         return
     try:
-        obj = ioc.loader.import_symbol(qualname)
+        obj = importlib.import_module(qualname)
     except ImportError:
         warnings.warn(
             f"UNIMATRIX_BOOT_MODULE points to a non-existant symbol: "
